@@ -7,27 +7,32 @@ pub mod settings;
 
 use std::process;
 use std::cmp::Reverse;
-use std::sync::mpsc;
+use std::sync::{mpsc, Arc};
 
 use clap::ArgMatches;
+use ureq::{AgentBuilder, Agent};
 
 use types::{Settings, UserParameters, Website, Media, Sort, Torrent};
 
 pub fn run(args: ArgMatches) {
     let user_parameters = UserParameters::get_params(args);
 
-    let (tx, rx) = mpsc::channel();
+    let client = Arc::new(match build_http_client(&user_parameters.proxy) {
+        Ok(client) => client,
+        Err(_) => Agent::new(),
+    });
 
+    let (tx, rx) = mpsc::channel();
     for website in user_parameters.websites {
         match website {
             Website::Nyaa => {
-                nyaa::query(tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
+                nyaa::query(&client, tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
             },
             Website::Piratebay => { 
-                piratebay::query(tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
+                piratebay::query(&client, tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
             },
             Website::YTS => {
-                yts::query(tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
+                yts::query(&client, tx.clone(), &user_parameters.search_query, user_parameters.search_depth)
             }
         };
     }
@@ -57,6 +62,17 @@ pub fn run(args: ArgMatches) {
     }
 }
 
+fn build_http_client(proxy: &str) -> Result<Agent, ureq::Error> {
+    if proxy.is_empty() {
+        Ok(Agent::new())
+    }
+    else {
+        Ok(AgentBuilder::new()
+            .proxy(ureq::Proxy::new(proxy)?)
+            .build())
+    }
+}
+
 fn download_torrent(dir: &str, magnet: &str) {
     if let Err(err) = process::Command::new("sudo")
         .arg("deluge-console")
